@@ -17,13 +17,13 @@
  *
  * Authors:   Carsten Lucke <luckec@tool-garage.de>
  *
- * CVS file id: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
+ * CVS file id: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
  *
  * @category Date
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
+ * @version  CVS: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
@@ -35,7 +35,7 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
+ * @version  CVS: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
@@ -119,7 +119,7 @@ define('DATE_HOLIDAYS_DRIVER_IDENTIFY_ISO3166_METHOD', 'getISO3166Codes');
  * @subpackage Driver
  * @author     Carsten Lucke <luckec@tool-garage.de>
  * @license    http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version    CVS: $Id: Driver.php 296182 2010-03-14 13:01:24Z kguest $
+ * @version    CVS: $Id: Driver.php 321620 2011-12-31 20:59:14Z danielc $
  * @link       http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver
@@ -301,23 +301,30 @@ class Date_Holidays_Driver
      */
     function addTranslation($locale)
     {
-        $data_dir = "/usr/obj/pear-Date-Holidays-0.21.5/fake-i386/var/www/pear/data";
+        $data_dir = "/usr/obj/pear-Date-Holidays-0.21.6/fake-amd64/var/www/pear/data";
         $bestLocale = $this->_findBestLocale($locale);
         $matches = array();
         $loaded = false;
 
-        //Christian driver is exceptional...
-        if ($this->_driverName == 'Christian') {
-            $stubdir = "$data_dir/Date_Holidays/lang/Christian/";
+        if ($data_dir == '@'.'DATA-DIR'.'@') {
+            $data_dir = dirname(dirname(dirname(__FILE__))); 
+            $stubdirs = array(
+                "$data_dir/lang/{$this->_driverName}/",
+                "$data_dir/lang/Christian/");
         } else {
-            $stubdir = "$data_dir/Date_Holidays_{$this->_driverName}/lang/{$this->_driverName}/";
-            if (! is_dir($stubdir)) {
-                $stubdir = $data_dir . "/Date_Holidays/lang/";
+            //Christian driver is exceptional...
+            if ($this->_driverName == 'Christian') {
+                $stubdir = "$data_dir/Date_Holidays/lang/Christian/";
+            } else {
+                $stubdir = "$data_dir/Date_Holidays_{$this->_driverName}/lang/{$this->_driverName}/";
+                if (! is_dir($stubdir)) {
+                    $stubdir = $data_dir . "/Date_Holidays/lang/";
+                }
             }
+            $stubdirs = array(
+                $stubdir,
+                "$data_dir/Date_Holidays_{$this->_driverName}/lang/Christian/");
         }
-        $stubdirs = array(
-            $stubdir,
-            "$data_dir/Date_Holidays_{$this->_driverName}/lang/Christian/");
 
         foreach ($stubdirs as $stubdir) {
             if (is_dir($stubdir)) {
@@ -690,6 +697,11 @@ class Date_Holidays_Driver
                 return $date;
             }
         }
+
+        if ($date->getYear() != $this->_year) {
+            return null;
+        }
+
         $isodate = mktime(0,
                           0,
                           0,
