@@ -8,38 +8,40 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: AllTests.php 308789 2011-03-01 02:25:46Z clockwerx $
+ * @version  CVS: $Id: AllTests.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Date_Holidays_AllTests::main');
 }
 
-require_once 'PHPUnit/TextUI/TestRunner.php';
-
-require_once 'Date_Holidays_TestSuite.php';
-require_once 'Date_Holidays_Driver_TestSuite.php';
-require_once 'Date_Holidays_Bugfix_Retests_TestSuite.php';
-require_once 'Date_Holidays_Driver_Austria_TestSuite.php';
-require_once 'Date_Holidays_Driver_Australia_TestSuite.php';
-require_once 'Date_Holidays_Driver_AustraliaSA_TestSuite.php';
-require_once 'Date_Holidays_Driver_AustraliaNSW_TestSuite.php';
-require_once 'Date_Holidays_Driver_AustraliaWA_TestSuite.php';
-require_once 'Date_Holidays_Driver_AustraliaQLD_TestSuite.php';
-require_once 'Date_Holidays_Driver_Brazil_TestSuite.php';
-require_once 'Date_Holidays_Driver_Christian_TestSuite.php';
-require_once 'Date_Holidays_Driver_EnglandWales_TestSuite.php';
-require_once 'Date_Holidays_Driver_Germany_TestSuite.php';
-require_once 'Date_Holidays_Driver_Iceland_TestSuite.php';
-require_once 'Date_Holidays_Driver_Ireland_TestSuite.php';
-require_once 'Date_Holidays_Driver_Jewish_TestSuite.php';
-require_once 'Date_Holidays_Driver_PHPdotNet_TestSuite.php';
-require_once 'Date_Holidays_Driver_Romania_TestSuite.php';
-require_once 'Date_Holidays_Driver_Ukraine_TestSuite.php';
-require_once 'Date_Holidays_Driver_UNO_TestSuite.php';
-require_once 'Date_Holidays_Driver_USA_TestSuite.php';
-require_once 'Date_Holidays_Driver_Sweden_TestSuite.php';
+/** Set up the environment */
+require_once dirname(__FILE__) . '/helper.inc';
 
+$dir = dirname(__FILE__);
+require_once "$dir/Date_Holidays_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_TestSuite.php";
+require_once "$dir/Date_Holidays_Bugfix_Retests_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Austria_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Australia_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_AustraliaSA_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_AustraliaNSW_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_AustraliaWA_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_AustraliaQLD_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Brazil_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Christian_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_EnglandWales_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Germany_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Iceland_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Ireland_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Jewish_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_PHPdotNet_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Romania_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Ukraine_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_UNO_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_USA_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Sweden_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Finland_TestSuite.php";
 
 /**
  * a test class for running all Date_Holidays unit tests
@@ -48,7 +50,7 @@ require_once 'Date_Holidays_Driver_Sweden_TestSuite.php';
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: AllTests.php 308789 2011-03-01 02:25:46Z clockwerx $
+ * @version  CVS: $Id: AllTests.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_AllTests
