@@ -8,28 +8,29 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: AllTestsUndeployed.php 294977 2010-02-12 04:51:47Z clockwerx $
+ * @version  CVS: $Id: AllTestsUndeployed.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
-error_reporting(E_ALL);
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'AllTestsUndeployed::main');
 }
 
-require_once 'PHPUnit/TextUI/TestRunner.php';
+/** Set up the environment */
+require_once dirname(__FILE__) . '/helper.inc';
 
-require_once 'Date_Holidays_TestSuite.php';
-require_once 'Date_Holidays_Driver_TestSuite.php';
-require_once 'Date_Holidays_Bugfix_Retests_TestSuite.php';
-require_once 'Date_Holidays_Driver_Christian_TestSuite.php';
-require_once 'Date_Holidays_Driver_Germany_TestSuite.php';
-require_once 'Date_Holidays_Driver_Jewish_TestSuite.php';
-require_once 'Date_Holidays_Driver_PHPdotNet_TestSuite.php';
-require_once 'Date_Holidays_Driver_UNO_TestSuite.php';
-require_once 'Date_Holidays_Driver_USA_TestSuite.php';
-require_once 'Date_Holidays_Driver_Sweden_TestSuite.php';
+$dir = dirname(__FILE__);
+require_once "$dir/Date_Holidays_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_TestSuite.php";
+require_once "$dir/Date_Holidays_Bugfix_Retests_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Christian_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Germany_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Jewish_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_PHPdotNet_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_UNO_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_USA_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Sweden_TestSuite.php";
+require_once "$dir/Date_Holidays_Driver_Finland_TestSuite.php";
 
 /**
  * a test class for running all Date_Holidays unit tests whilst the package is undeployed.
@@ -38,7 +39,7 @@ require_once 'Date_Holidays_Driver_Sweden_TestSuite.php';
  * @package  Date_Holidays
  * @author   Ken Guest <kguest@php.net>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: AllTestsUndeployed.php 294977 2010-02-12 04:51:47Z clockwerx $
+ * @version  CVS: $Id: AllTestsUndeployed.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 class AllTestsUndeployed
