@@ -8,14 +8,12 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_Jewish_TestSuite.php 308791 2011-03-01 02:34:59Z clockwerx $
+ * @version  CVS: $Id: Date_Holidays_Driver_Jewish_TestSuite.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
-if (!defined("PHPUnit_MAIN_METHOD")) {
-    define("PHPUnit_MAIN_METHOD", "Date_HolidaysTest::main");
-}
 
-require_once 'Date/Holidays.php';
+/** Set up the environment */
+require_once dirname(__FILE__) . '/helper.inc';
 
 /**
  * Test class for running unit tests related to the driver for Jewish Holidays
@@ -25,7 +23,7 @@ require_once 'Date/Holidays.php';
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: Date_Holidays_Driver_Jewish_TestSuite.php 308791 2011-03-01 02:34:59Z clockwerx $
+ * @version  CVS: $Id: Date_Holidays_Driver_Jewish_TestSuite.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 class Date_Holidays_Driver_Jewish_TestSuite extends PHPUnit_Framework_TestCase
