@@ -8,16 +8,15 @@
  * @package  Date_Holidays
  * @author   Carsten Lucke <luckec@tool-garage.de>
  * @license  http://www.php.net/license/3_01.txt PHP License 3.0.1
- * @version  CVS: $Id: test_getHolidays.php 260147 2008-05-22 23:50:30Z kguest $
+ * @version  CVS: $Id: test_getHolidays.php 321621 2011-12-31 21:00:35Z danielc $
  * @link     http://pear.php.net/package/Date_Holidays
  */
 
-error_reporting(E_ALL);
-
-require_once 'Date/Holidays.php';
+/** Set up the environment */
+require_once dirname(__FILE__) . '/helper.inc';
 
 $driver = Date_Holidays::factory('Germany', date('Y', time()), 'de');
-$langer = "/var/www/devel/pear/Date_Holidays/lang";
+$langer = helper_get_lang_dir('Date_Holidays');
 $driver->addTranslationFile($langer . '/Christian/de_DE.ini', 'de');
 $driver->addTranslationFile($langer . '/Germany/de_DE.ini', 'de');
 
